Generates a placeholder div for plot output with MCP data attributes.
Value
An htmltools::tagList with a scoped style and the plot container
Generates a placeholder div for plot output with MCP data attributes.
An htmltools::tagList with a scoped style and the plot container